@@ -50,7 +50,7 @@ Kamoso::~Kamoso()
 
 QUrl Kamoso::fileNameSuggestion(const QUrl &saveUrl, const QString &name, const QString& extension) const
 {
-    const QString date = QDateTime::currentDateTime().toString(QStringLiteral("yyyy-mm-dd_hh-mm-ss"));
+    const QString date = QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd_hh-mm-ss"));
     const QString initialName =  QStringLiteral("%1_%2.%3").arg(name, date, extension);
 
     QUrl path(saveUrl.toString() + '/' + initialName);
@@ -95,6 +95,7 @@ void Kamoso::setRecording(bool recording)
         m_recordingTimer.stop();
     }
 
+    Q_EMIT isRecordingChanged(m_recordingTimer.isActive());
 }
 
 QString Kamoso::recordingTime() const
