@@ -35,8 +35,8 @@ class WebcamControl : public QObject
         virtual ~WebcamControl();
 
     public Q_SLOTS:
-        void play();
-        void play(Device* device);
+        bool play();
+        bool play(Device* device);
         void stop();
         void takePhoto(const QUrl& url);
         void startRecording();
